@@ -100,12 +100,12 @@ function drush_main() {
           // Dispatch the command(s).
           $return = drush_dispatch($command);
 
-	  // prevent a '1' at the end of the output
-	  if ($return === TRUE) {
-	    $return = '';
-	  }
+          // prevent a '1' at the end of the output
+          if ($return === TRUE) {
+            $return = '';
+          }
 
-          if (drush_get_context('DRUSH_DEBUG')) {
+          if (drush_get_context('DRUSH_DEBUG') && !drush_get_context('DRUSH_QUIET')) {
             drush_print_timers();
           }
           drush_log(dt('Peak memory usage was !peak', array('!peak' => drush_format_size(memory_get_peak_usage()))), 'memory');
